@@ -17,9 +17,11 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
-#  version: 20220817152213
+#  version: 20220819111541
 
 from json import dumps
+import mimetypes
+from pathlib import Path
 import re
 from io import BytesIO as IO
 from datetime import datetime, timedelta
@@ -40,7 +42,7 @@ class InterceptorHandlerFactory:
     """
 
     @staticmethod
-    def getHandler(db):
+    def getHandler(db, static_directory):
         class InterceptorHandler(BaseHTTPRequestHandler):
             querypattern = re.compile(
                 r"^/sensorlog\?hum=(?P<humidity>\d+(\.\d+)?)\&temp=(?P<temperature>\d+(\.\d+)?)\&id=(?P<stationid>[a-z01-9-]+)$",
@@ -54,14 +56,32 @@ class InterceptorHandlerFactory:
                 r"^/html(\?id=(?P<stationid>[a-z01-9-]+))?$",
                 re.IGNORECASE,
             )
+            allpattern = re.compile(
+                r"^/all$",
+                re.IGNORECASE,
+            )
+
             jsonpattern = re.compile(
-                r"^/json(\?id=(?P<stationid>[a-z01-9-]+))?$",
+                r"^/json(?P<p24>/24)?(\?id=(?P<stationid>[a-z01-9-]+))?$",
                 re.IGNORECASE,
             )
             namespattern = re.compile(
                 r"^(/name\?id=(?P<stationid>[a-z01-9-]+)\&name=(?P<name>([a-z01-9-]|\s)+))|(/names)$",
                 re.IGNORECASE,
             )
+            staticpattern = re.compile(
+                r"^/static/(?P<resource>.+)$",
+                re.IGNORECASE,
+            )
+
+            @staticmethod
+            def getTimeseries(db, stationid):
+                mark = datetime.now() - timedelta(days=1)
+                mtime = db.retrieveDatetimeBefore(stationid, mark)
+                return db.retrieveMeasurements(
+                    stationid,
+                    mtime if mtime is not None else mark,
+                )
 
             def do_GET(self):
                 logging.info(self.path)
@@ -86,6 +106,7 @@ class InterceptorHandlerFactory:
                         self.end_headers()
                         self.wfile.write(png)
                         f.close()
+                        return
                     elif m := re.match(self.htmlpattern, self.path):
                         ms = db.retrieveLastMeasurement(m.group("stationid"))
                         mdivs = "\n".join(
@@ -98,28 +119,21 @@ class InterceptorHandlerFactory:
                             </div>"""
                             for m in ms
                         )
-                        style = """
-                        .body {width:100%; }
-                        .measurements {width: 90%;}
-                        .measurement {float:left; width:200px;}
-                        .station {float:left; font-size:16pt;}
-                        .time {float:left; font-size:12pt;}
-                        .temp {float:left; clear:both; font-size:40pt;}
-                        .hum {float:left; font-size:12pt;}
-                        .late { background-color:red; }
-                        """
                         html = bytes(
-                            f"""<html>
-                        <head><meta charset="UTF-8"><meta http-equiv="refresh" content="300"><title>Temperatuur binnen</title>
-                        <style>{style}</style>
-                        </head>
-                        <body>
-                        <div class="measurements">
-                        {mdivs}
-                        </div>
-                        </body>
-                        <script>document.querySelectorAll("[data-time]").forEach(function(e){{d=new Date(e.getAttribute("data-time"));e.innerHTML=d.getHours() + ":" + d.getMinutes().toString().padStart(2, '0')}})</script>
-                        </html>
+                            f"""
+<html>
+<head>
+<meta charset="UTF-8">
+<meta http-equiv="refresh" content="300">
+<title>Temperatuur binnen</title>
+<link href="/static/css/stylesheet.css" rel="stylesheet"></head>
+<body>
+<div class="measurements">
+{mdivs}
+</div>
+</body>
+<script>document.querySelectorAll("[data-time]").forEach(function(e){{d=new Date(e.getAttribute("data-time"));e.innerHTML=d.getHours() + ":" + d.getMinutes().toString().padStart(2, '0')}})</script>
+</html>
                         """,
                             "UTF-8",
                         )
@@ -128,19 +142,83 @@ class InterceptorHandlerFactory:
                         self.send_header("Content-Length", str(len(html)))
                         self.end_headers()
                         self.wfile.write(html)
-                    elif m := re.match(self.jsonpattern, self.path):
-                        json = bytes(
-                            dumps(
-                                db.retrieveLastMeasurement(m.group("stationid")),
-                                cls=DatetimeEncoder,
-                            ),
-                            encoding="UTF-8",
+                        return
+                    elif m := re.match(self.allpattern, self.path):
+                        last_measurements = db.retrieveLastMeasurement()
+                        station_data = dumps(
+                            last_measurements,
+                            cls=DatetimeEncoder,
                         )
+                        time_series = {
+                            s["stationid"]: InterceptorHandler.getTimeseries(
+                                db, s["stationid"]
+                            )
+                            for s in last_measurements
+                        }
+                        temperature_data_map = dumps(time_series, cls=DatetimeEncoder)
+                        html = bytes(
+                            """<html>
+<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js" integrity="sha256-/xUj+3OJU5yExlq6GSYGSHk7tPXikynS7ogEvDej/m4=" crossorigin="anonymous"></script>
+<script src="https://cdn.jsdelivr.net/npm/chart.js@3.9.1/dist/chart.min.js" integrity="sha256-+8RZJua0aEWg+QVVKg4LEzEEm/8RFez5Tb4JBNiV5xA=" crossorigin="anonymous"></script>
+<script src="https://cdn.jsdelivr.net/npm/chartjs-adapter-date-fns/dist/chartjs-adapter-date-fns.bundle.min.js"></script>
+<head>
+    <meta charset="UTF-8">
+    <meta http-equiv="refresh" content="300">
+    <title>Indoor temperature</title>
+    <link href="/static/css/stylesheet.css" rel="stylesheet">
+</head>
+<body>
+    <div id="measurements"></div>
+</body>
+<script>
+    station_data = """
+                            + station_data
+                            + """;
+    temperature_data_map = """
+                            + temperature_data_map
+                            + """;
+</script>
+<script src="static/js/layout.js"></script>
+</html>
+""",
+                            "UTF-8",
+                        )
+                        self.send_response(HTTPStatus.OK)
+                        self.send_header("Content-type", "text/html")
+                        self.send_header("Content-Length", str(len(html)))
+                        self.end_headers()
+                        self.wfile.write(html)
+                        return
+                    elif m := re.match(self.jsonpattern, self.path):
+                        if m.group("p24") is not None:
+                            mark = datetime.now() - timedelta(days=1)
+                            mtime = db.retrieveDatetimeBefore(
+                                m.group("stationid"), mark
+                            )
+                            json = bytes(
+                                dumps(
+                                    db.retrieveMeasurements(
+                                        m.group("stationid"),
+                                        mtime if mtime is not None else mark,
+                                    ),
+                                    cls=DatetimeEncoder,
+                                ),
+                                encoding="UTF-8",
+                            )
+                        else:
+                            json = bytes(
+                                dumps(
+                                    db.retrieveLastMeasurement(m.group("stationid")),
+                                    cls=DatetimeEncoder,
+                                ),
+                                encoding="UTF-8",
+                            )
                         self.send_response(HTTPStatus.OK)
                         self.send_header("Content-type", "application/json")
                         self.send_header("Content-Length", str(len(json)))
                         self.end_headers()
                         self.wfile.write(json)
+                        return
                     elif m := re.match(self.namespattern, self.path):
                         if not self.path.startswith("/names"):
                             stationid = m.group("stationid")
@@ -159,6 +237,21 @@ class InterceptorHandlerFactory:
                         self.send_header("Content-Length", str(len(html)))
                         self.end_headers()
                         self.wfile.write(bytes(html, "UTF-8"))
+                        return
+                    elif m := re.match(self.staticpattern, self.path):
+                        filepath = Path(static_directory) / m.group("resource")
+                        mime_type = mimetypes.guess_type(filepath)[0]
+                        try:
+                            with open(filepath, "rb") as f:
+                                b = f.read()
+                                self.send_response(HTTPStatus.OK)
+                                self.send_header("Content-type", mime_type)
+                                self.send_header("Content-Length", str(len(b)))
+                                self.end_headers()
+                                self.wfile.write(b)
+                                return
+                        except FileNotFoundError:
+                            self.send_response(HTTPStatus.NOT_FOUND)
                     else:
                         self.send_response(HTTPStatus.FORBIDDEN)
                 except Exception as e:
@@ -172,5 +265,7 @@ class InterceptorHandlerFactory:
 class Interceptor(ThreadingHTTPServer):
     allow_reuse_address = True
 
-    def __init__(self, server_address, db):
-        super().__init__(server_address, InterceptorHandlerFactory.getHandler(db))
+    def __init__(self, server_address, db, static_directory):
+        super().__init__(
+            server_address, InterceptorHandlerFactory.getHandler(db, static_directory)
+        )
